@@ -481,7 +481,8 @@ def updateGoogleEvent(evt, googleid, pid):
 		rec_data = create_rrule(start_time, end_time, evt.get_rrule())
 		event.recurrence = gdata.calendar.Recurrence(text=rec_data)
 		if len(event.reminder) > 0:
-			event.reminder[0].minutes = evt.get_alarm()
+			pass
+			#event.reminder[0].minutes = evt.get_alarm()
 		else:
 			event.reminder.append(gdata.calendar.Reminder(minutes=evt.get_alarm()));
 	else:
